library bubble_overlay;

import 'dart:io';
import 'package:flutter/services.dart';

class BubbleOverlay {
  String _customText;

  BubbleOverlay() {
    if (!Platform.isAndroid)
      throw PlatformException(
          code: 'Bubble overlay only available for Android');
  }

  static const _platform = const MethodChannel('bubble_overlay');

  void openBubble(
    String customText,
    String textColor,
    String backgroundColor,
    String topIconAsset,
    String bottomIconAsset,
  ) async {
    var bytesTop = topIconAsset == null
        ? null
        : (await rootBundle.load(topIconAsset)).buffer.asUint8List();
    var bytesBottom = bottomIconAsset == null
        ? null
        : (await rootBundle.load(bottomIconAsset)).buffer.asUint8List();
    _platform.invokeMethod(
      'openBubble',
      [
        customText,
        textColor,
        backgroundColor,
        bytesTop,
        bytesBottom,
      ],
    );
  }

  void updateBubbleText(String text) =>
      _platform.invokeMethod('updateBubbleText', text);

  void updateTextColor(String textColor) =>
      _platform.invokeMethod('updateBubbleTextColor', textColor);

  void updateBubbleColor(String bubbleColor) =>
      _platform.invokeMethod('updateBubbleColor', bubbleColor);

  Future<void> updateTopIcon(String assetImage) async {
    var bytes = (await rootBundle.load(assetImage)).buffer.asUint8List();
    _platform.invokeMethod('updateBubbleTopIcon', bytes);
  }

  Future<void> updateBottomIcon(String assetImage) async {
    var bytes = (await rootBundle.load(assetImage)).buffer.asUint8List();
    _platform.invokeMethod('updateBubbleBottomIcon', bytes);
  }

  String get text => _customText;

  set text(String text) {
    _customText = text;
    updateBubbleText(text);
  }
}
